@@ -17,7 +17,7 @@ use Zing::Registry;
 use FlightRecorder;
 use File::Spec;
 
-our $VERSION = '0.12'; # VERSION
+our $VERSION = '0.13'; # VERSION
 
 our $name = 'zing <{command}> [<{app}>] [options]';
 
@@ -26,26 +26,30 @@ our $name = 'zing <{command}> [<{app}>] [options]';
 sub auto {
   {
     clean => '_handle_clean',
+    install => '_handle_install',
     logs => '_handle_logs',
+    monitor => '_handle_monitor',
     pid => '_handle_pid',
     restart => '_handle_restart',
-    monitor => '_handle_monitor',
-    update => '_handle_update',
     start => '_handle_start',
     stop => '_handle_stop',
+    terms => '_handle_terms',
+    update => '_handle_update',
   }
 }
 
 sub subs {
   {
     clean => 'Prune the process registry',
+    install => 'Create an application cartridge',
     logs => 'Tap logs and output to STDOUT',
+    monitor => 'Monitor the specified application (start if not started)',
     pid => 'Display an application process ID',
     restart => 'Restart the specified application',
-    monitor => 'Monitor the specified application (start if not started)',
-    update => 'Hot-reload application processes',
     start => 'Start the specified application',
     stop => 'Stop the specified application',
+    terms => 'Display resource identifiers (under specified namespace)',
+    update => 'Hot-reload application processes',
   }
 }
 
@@ -61,6 +65,11 @@ sub spec {
       type => 'flag',
       flag => 'b',
     },
+    handle => {
+      desc => 'Provide a handle (namespace)',
+      type => 'string',
+      flag => 'h',
+    },
     global => {
       desc => 'Tap the "global" log channel (defaults to "local")',
       type => 'flag',
@@ -82,6 +91,11 @@ sub spec {
       flag => 'I',
       args => '@',
     },
+    package => {
+      desc => 'Provide a process package name',
+      type => 'string',
+      flag => 'P',
+    },
     piddir => {
       desc => 'Directory for the pid file',
       type => 'string',
@@ -111,7 +125,11 @@ sub _handle_clean {
 
   my $r = Zing::Registry->new;
 
-  for my $id (@{$r->ids}) {
+  if ($self->opts->handle) {
+    $ENV{ZING_HANDLE} = $self->opts->handle;
+  }
+
+  for my $id (@{$r->keys}) {
     my $data = $r->store->recv($id) or next;
     my $pid = $data->{process} or next;
     $r->store->drop($id) unless kill 0, $pid;
@@ -120,15 +138,92 @@ sub _handle_clean {
   return $self;
 }
 
+sub _handle_install {
+  my ($self) = @_;
+
+  my $app = $self->args->app;
+
+  if (!$app) {
+    print $self->help, "\n";
+    return $self->okay;
+  }
+
+  my $appdir  = $self->opts->appdir;
+  my $libdir  = $self->opts->libdir;
+  my $package = $self->opts->package;
+
+  unshift @INC, @$libdir if $libdir;
+
+  if (!$package) {
+    print "No package was provided\n";
+    return $self->fail;
+  }
+
+  require Data::Object::Space;
+
+  my $space = Data::Object::Space->new($package);
+
+  if (!$space->tryload) {
+    print "Package provided could not be loaded: @{[$space->package]}\n";
+    return $self->fail;
+  }
+
+  if (!$space->package->can("install")) {
+    print "Package provided can't be installed: @{[$space->package]}\n";
+    return $self->fail;
+  }
+
+  $appdir ||= $ENV{ZING_APPDIR} || $ENV{ZING_HOME} || File::Spec->curdir;
+
+  my $appfile = File::Spec->catfile($appdir, $app);
+
+  if (-e $appfile) {
+    print "Cartridge already exists: $appfile\n";
+    return $self->fail;
+  }
+
+  require Data::Dumper;
+
+  no warnings 'once';
+
+  local $Data::Dumper::Indent = 0;
+  local $Data::Dumper::Purity = 0;
+  local $Data::Dumper::Quotekeys = 0;
+  local $Data::Dumper::Deepcopy = 1;
+  local $Data::Dumper::Deparse = 1;
+  local $Data::Dumper::Sortkeys = 1;
+  local $Data::Dumper::Terse = 1;
+  local $Data::Dumper::Useqq = 1;
+
+  my $service = $space->package->new;
+
+  open(my $fh, ">", "$appfile") or do {
+    print "Can't create cartridge $appfile: $!";
+    $self->fail;
+  };
+  print $fh Data::Dumper::Dumper($service->install);
+  close $fh;
+
+  print "Cartridge created: $appfile\n";
+
+  return $self;
+}
+
 sub _handle_logs {
   my ($self) = @_;
 
   my $c = Zing::Channel->new(
     name => '$journal',
-    (target => $self->opts->global ? 'global' : 'local')
+    (target => $self->opts->global ? 'global' : $ENV{ZING_TARGET} || 'local')
   );
 
-  $c->reset if $self->opts->backlog;
+  if ($self->opts->backlog) {
+    $c->reset;
+  }
+
+  if ($self->opts->handle) {
+    $ENV{ZING_HANDLE} = $self->opts->handle;
+  }
 
   while (1) {
     next unless my $info = $c->recv;
@@ -174,15 +269,22 @@ sub _handle_monitor {
     return $self->okay;
   }
 
+  my $appdir = $self->opts->appdir;
   my $piddir = $self->opts->piddir
     || $ENV{ZING_PIDDIR}
     || $ENV{ZING_HOME}
     || File::Spec->curdir;
 
+  $appdir ||= $ENV{ZING_APPDIR} || $ENV{ZING_HOME} || File::Spec->curdir;
+
+  my $appfile = File::Spec->catfile($appdir, $app);
   my $pidfile = File::Spec->catfile($piddir, "$app.pid");
 
   $self->opts->tag($app) if !$self->opts->tag;
   $self->_handle_start if !-e $pidfile;
+
+  do $appfile if -e $appfile;
+
   $self->_handle_logs;
 
   return $self;
@@ -247,6 +349,10 @@ sub _handle_start {
 
   unshift @INC, @$libdir if $libdir;
 
+  if ($self->opts->handle) {
+    $ENV{ZING_HANDLE} = $self->opts->handle;
+  }
+
   $appdir ||= $ENV{ZING_APPDIR} || $ENV{ZING_HOME} || File::Spec->curdir;
 
   my $appfile = File::Spec->catfile($appdir, $app);
@@ -314,6 +420,27 @@ sub _handle_stop {
   return $self;
 }
 
+sub _handle_terms {
+  my ($self) = @_;
+
+  if ($self->opts->handle) {
+    $ENV{ZING_HANDLE} = $self->opts->handle;
+  }
+
+  my $registry = Zing::Registry->new;
+  my $terms = $registry->store->keys((split /:/, $registry->term)[0,1]);
+  my $search = $self->opts->search || [];
+  my $lines = [sort @$terms];
+
+  for my $search (@$search) {
+    @$lines = grep /$search/, @$lines;
+  }
+
+  print "$_\n" for sort @$lines;
+
+  return $self;
+}
+
 sub _handle_update {
   my ($self) = @_;
 
