@@ -15,7 +15,7 @@ extends 'Zing::PubSub';
 
 use Zing::Term;
 
-our $VERSION = '0.12'; # VERSION
+our $VERSION = '0.13'; # VERSION
 
 # ATTRIBUTES
 
@@ -39,7 +39,7 @@ has 'process' => (
 # BUILDERS
 
 fun new_target($self) {
-  'global'
+  $ENV{ZING_TARGET} || 'global'
 }
 
 # METHODS
